@@ -1,30 +1,13 @@
-import requests
-import pprint
 from python_nbaclient import REQ_HEADER
 from python_nbaclient.constants import EndPoints, StatusCode
-from python_nbaclient.constants import CURRENT_SEASON, LEAGUE_ID
+from python_nbaclient.constants import CURRENT_SEASON, LEAGUE_ID, TEAM_TO_ID, ID_TO_TEAM
 from python_nbaclient.utils import Query, Output
 
 endpoints = EndPoints().endpoints
-status_code = StatusCode.status_code
+status_code = StatusCode().status_code
 output = Output()
 query = Query()
 
-class TeamList:
-    def __init__(self, league_id=LEAGUE_ID):
-        """
-        :param league_id String: id of the league
-        """
-        self._url = endpoints["CommonTeamYear"]
-        self._api_param = {"LeagueID": league_id}
-
-        resp = query.get_stats(url = self._url, headers = REQ_HEADER, api_param = self._api_param)
-        if resp.status_code == status_code["OK"]:
-            self.team_list = query.convert_to_json()
-            output.pretty_json(self.team_list)
-        else:
-            raise Exception("Response is not 200")
-
 
 class TeamDetails:
     def __init__(self, team_id):
@@ -34,10 +17,11 @@ class TeamDetails:
         self._url = endpoints["TeamDetails"]
         self._api_param = {"teamID": team_id}
 
-        resp = query.get_stats(url = self._url, headers = REQ_HEADER, api_param = self._api_param)
-        if resp.status_code == status_code["OK"]:
-            self.team_list = query.convert_to_json()
-            output.pretty_json(self.team_list)
+        self.resp = query.get_stats(url=self._url,
+                                    headers=REQ_HEADER,
+                                    api_param=self._api_param)
+        if self.resp.status_code == status_code["OK"]:
+            output.pretty_json(query.convert_to_json())
         else:
             raise Exception("Response is not 200")
 
@@ -62,10 +46,11 @@ class CommonTeamRoster:
             "Season": season
         }
 
-        resp = query.get_stats(url = self._url, headers = REQ_HEADER, api_param = self._api_param)
-        if resp.status_code == status_code["OK"]:
-            self.team_list = query.convert_to_json()
-            output.pretty_json(self.team_list)
+        self.resp = query.get_stats(url=self._url,
+                                    headers=REQ_HEADER,
+                                    api_param=self._api_param)
+        if self.resp.status_code == status_code["OK"]:
+            output.pretty_json(query.convert_to_json())
         else:
             raise Exception("Response is not 200")
 
@@ -82,10 +67,11 @@ class FranchiseLeaders:
         self._url = endpoints["FranchiseLeaders"]
         self._api_param = {"TeamID": team_id}
 
-        resp = query.get_stats(url = self._url, headers = REQ_HEADER, api_param = self._api_param)
-        if resp.status_code == status_code["OK"]:
-            self.team_list = query.convert_to_json()
-            output.pretty_json(self.team_list)
+        self.resp = query.get_stats(url=self._url,
+                                    headers=REQ_HEADER,
+                                    api_param=self._api_param)
+        if self.resp.status_code == status_code["OK"]:
+            output.pretty_json(query.convert_to_json())
         else:
             raise Exception("Response is not 200")
 
